@@ -1,27 +1,47 @@
 mod git;
 mod preserves;
+mod subcommands;
 
-use clap::{App, Arg};
+use clap::{App, AppSettings, Arg, crate_authors, crate_version};
 use preserves::{Check, Summary, CheckList, datasource::{STATUS, REFS, REMOTE}};
 use tera::{Tera, Context};
 use lazy_static::lazy_static;
+use include_dir::{include_dir,Dir,DirEntry};
+use std::path::Path;
 
 lazy_static! {
+  pub static ref TEMPLATES: Dir<'static> = include_dir!("src/templates");
   pub static ref TMPL: Tera = {
     let mut tera = Tera::default();
-    tera.add_raw_template("macros", include_str!("templates/macros.txt")).expect("macros to parse");
-    tera.add_raw_template("summary", include_str!("templates/summary.txt")).expect("summary to parse");
-    tera.add_raw_template("statusline", include_str!("templates/statusline.txt")).expect("statusline to parse");
-    tera.add_raw_template("debug", include_str!("templates/debug.txt")).expect("debug to parse");
+    template_files(|tname, body| {
+      tera.add_raw_template(tname, body).expect(&*format!("{} to parse", tname));
+    });
     tera
   };
 }
 
+fn template_files(mut func: impl FnMut(&str, &str)) {
+  for entry in TEMPLATES.find("**/*.txt").expect("static dir") {
+    if let DirEntry::File(f) = entry {
+      let tpath = f.path().with_extension("");
+      let tname = tpath.to_str().expect("utf8 pathname");
+      let body = f.contents_utf8().expect(&*format!("{} contents", tname));
+      func(tname, body)
+    }
+  }
+}
+
 fn main() -> ! {
   let opt = App::new("Confit")
-    .version(option_env!("CARGO_PKG_VERSION").unwrap_or("dev"))
-    .author("Judson Lester <nyarly@gmail.com>")
+    //.version(option_env!("CARGO_PKG_VERSION").unwrap_or("dev"))
+    .version(crate_version!())
+    .author(crate_authors!(", "))
+    .setting(AppSettings::VersionlessSubcommands)
+    .setting(AppSettings::ColoredHelp)
     .about("makes sure your work is properly preserved in git")
+    .long_about(include_str!("about.txt"))
+    .after_help(include_str!("after.txt"))
+    .subcommand(subcommands::write_templates::def())
     .arg(
       Arg::with_name("debug")
       .long("debug")
@@ -33,26 +53,46 @@ fn main() -> ! {
       .short("q")
       .help("suppress normal state summary; scripts can rely on the status code")
       .conflicts_with("format")
+      .conflicts_with("template")
     )
     .arg(
       Arg::with_name("format")
       .long("format")
       .short("f")
-      .help("choose a format for output")
-      .possible_values(TMPL.get_template_names()
-        .filter(|&n| n != "macros")
-        .collect::<Vec<_>>().as_slice())
+      .help(format!("choose a format for output [included: {}]",
+          TMPL.get_template_names()
+          .filter(|&n| n != "macros")
+          .collect::<Vec<_>>().as_slice().join(", ")).as_ref())
       .default_value("summary")
     )
+    .arg(
+      Arg::with_name("template")
+      .long("template")
+      .short("T")
+      .help("provide a template source directory")
+      .takes_value(true)
+    )
     .arg(
       Arg::with_name("checks")
-      .short("checks")
+      .long("checks")
+      .short("c")
       .use_delimiter(true)
       .takes_value(true)
       .multiple(true)
       .possible_values(&Check::all_tags()))
     .get_matches();
 
+    if let (name, Some(sub_opt)) = opt.subcommand() {
+      match name {
+        "write-templates" => subcommands::write_templates::run(sub_opt),
+        _ => {
+          println!("Unknown subcommand: {}", name);
+        } //?
+      }
+
+      std::process::exit(0)
+    }
+
     let mut checks = if let Some(tags) = opt.values_of("checks") {
       Check::tagged_checks(tags)
     } else {
@@ -99,10 +139,21 @@ fn main() -> ! {
       let mut context = Context::default();
       context.insert("items", &summary.items());
       context.insert("status", &summary.status);
-      print!("{}",
+      let body = if let Some(tdir) = opt.value_of("template") {
+        let tpath = Path::new(tdir).join("**");
+        let t = Tera::new(
+          tpath.to_str()
+          .ok_or("couldn't convert path to utf8")
+          .unwrap_or_else(&error_status(133))
+        ).unwrap_or_else(&error_status(132));
+        t.render(opt.value_of("format").expect("format has no value"), &context)
+          .unwrap_or_else(&error_status(131))
+      } else {
         TMPL.render(opt.value_of("format").expect("format has no value"), &context)
-        .unwrap_or_else(&error_status(131))
-      )
+          .unwrap_or_else(&error_status(131))
+      };
+
+      print!("{}", body);
     }
 
     std::process::exit(summary.exit_status())
